@@ -73,7 +73,11 @@ class PtloginBackend(ModelBackend):
         api_params = {"app_code": settings.APP_CODE, "skey": skey, "uin": uin}
         # noinspection PyBroadException
         try:
-            response = send(resolve_login_url(ConfFixture.VERIFY_URL, request), "GET", api_params)
+            response = send(
+                resolve_login_url(ConfFixture.VERIFY_URL, request, "http"),
+                "GET",
+                api_params,
+            )
             if not response["result"]:
                 logger.error(u"uin，skey 验证失败，error=%s" % response["message"])
                 return False
