@@ -11,9 +11,11 @@ an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express o
 specific language governing permissions and limitations under the License.
 """
 
+import os
 import django
 
 from blueapps.core.handler.wsgi import BkWSGIHandler
+from blueapps.opentelemetry.metrics.server import start_metrics_http_server
 
 
 def get_wsgi_application():
@@ -25,4 +27,8 @@ def get_wsgi_application():
     case the internal WSGI implementation changes or moves in the future.
     """
     django.setup(set_prefix=False)
+
+    if os.getenv("ENABLE_METRICS", False):
+        start_metrics_http_server()
+
     return BkWSGIHandler()
