@@ -24,10 +24,15 @@ from opentelemetry.exporter.jaeger.thrift import JaegerExporter
 from opentelemetry.exporter.otlp.proto.grpc.trace_exporter import OTLPSpanExporter
 
 from blueapps.opentelemetry.instrumentor import BKAppInstrumentor
+from blueapps.opentelemetry.metrics.instrumentor import SaaSMetricsInstrumentor
 
 
 def setup_trace_config(
-    service_name: str, bk_data_id: int, otel_sampler: str, otel_grpc_host: str
+    service_name: str,
+    bk_data_id: int,
+    otel_sampler: str,
+    otel_grpc_host: str,
+    bk_data_token: str = "",
 ):
     if settings.ENVIRONMENT == "dev":
         # local environment, use jaeger as trace service
@@ -51,6 +56,7 @@ def setup_trace_config(
                     {
                         "service.name": service_name,
                         "bk_data_id": bk_data_id,
+                        "bk.data.token": bk_data_token,
                     },
                 ),
                 sampler=_KNOWN_SAMPLERS[otel_sampler],
@@ -62,7 +68,10 @@ def setup_trace_config(
 
 
 def setup_by_settings():
-    if getattr(settings, "ENABLE_OTEL_TRACE", False):
+    enable_trace = os.getenv("ENABLE_TRACE", False) or getattr(
+        settings, "ENABLE_OTEL_TRACE", False
+    )
+    if enable_trace:
         service_name = (
             os.getenv("BKAPP_OTEL_SERVICE_NAME")
             or getattr(settings, "BKAPP_OTEL_SERVICE_NAME", None)
@@ -80,5 +89,16 @@ def setup_by_settings():
         otel_grpc_host = os.getenv("BKAPP_OTEL_GRPC_HOST") or getattr(
             settings, "BKAPP_OTEL_GRPC_HOST", None
         )
-        setup_trace_config(service_name, bk_data_id, otel_sampler, otel_grpc_host)
+        otel_bk_data_token = os.getenv("BKAPP_OTEL_BK_DATA_TOKEN") or getattr(
+            settings, "BKAPP_OTEL_BK_DATA_TOKEN", ""
+        )
+        setup_trace_config(
+            service_name,
+            bk_data_id,
+            otel_sampler,
+            otel_grpc_host,
+            bk_data_token=otel_bk_data_token,
+        )
         BKAppInstrumentor().instrument()
+    if os.getenv("ENABLE_METRICS", False):
+        SaaSMetricsInstrumentor().instrument()
